@@ -41,8 +41,6 @@
 #include "gedit-settings.h"
 #include "gedit-utils.h"
 
-#include "gseal-gtk-compat.h"
-
 #define ENCODING_KEY "Enconding"
 
 #define GEDIT_ENCODINGS_COMBO_BOX_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object),	\
@@ -448,6 +446,11 @@ gedit_encodings_combo_box_get_selected_encoding (GeditEncodingsComboBox *menu)
 	return NULL;
 }
 
+/**
+ * gedit_encodings_combo_box_set_selected_encoding:
+ * @menu:
+ * @encoding: (allow-none):
+ **/
 void
 gedit_encodings_combo_box_set_selected_encoding (GeditEncodingsComboBox *menu,
 						 const GeditEncoding    *encoding)
