@@ -648,18 +648,6 @@ on_max_recents_changed (GSettings     *settings,
 	 * update of the inline recents in the File menu */
 }
 
-static void
-on_active_plugins_changed (GSettings     *settings,
-			   const gchar   *key,
-			   GeditSettings *gs)
-{
-	GeditPluginsEngine *engine;
-
-	engine = gedit_plugins_engine_get_default ();
-
-	gedit_plugins_engine_active_plugins_changed (engine);
-}
-
 static void
 gedit_settings_init (GeditSettings *gs)
 {
@@ -680,17 +668,17 @@ initialize (GeditSettings *gs)
 	gs->priv->plugins = g_settings_get_child (G_SETTINGS (gs), "plugins");
 	
 	/* Load settings */
-	gs->priv->lockdown = g_settings_new ("org.gnome.Desktop.Lockdown");
+	gs->priv->lockdown = g_settings_new ("org.gnome.desktop.lockdown");
 	
 	g_signal_connect (gs->priv->lockdown,
 			  "changed",
 			  G_CALLBACK (on_lockdown_changed),
 			  NULL);
 
-	gs->priv->interface = g_settings_new ("org.gnome.Desktop.Interface");
+	gs->priv->interface = g_settings_new ("org.gnome.desktop.interface");
 	
 	g_signal_connect (gs->priv->interface,
-			  "changed",
+			  "changed::monospace-font-name",
 			  G_CALLBACK (on_system_font_changed),
 			  gs);
 
@@ -773,12 +761,6 @@ initialize (GeditSettings *gs)
 			  "changed::max-recents",
 			  G_CALLBACK (on_max_recents_changed),
 			  gs);
-
-	/* plugins changes */
-	g_signal_connect (gs->priv->plugins,
-			  "changed::active-plugins",
-			  G_CALLBACK (on_active_plugins_changed),
-			  gs);
 }
 
 static void
