@@ -26,7 +26,6 @@
 #include <string.h>
 #include <glib/gi18n-lib.h>
 #include <gio/gio.h>
-#include <gedit/gedit-plugin.h>
 #include <gedit/gedit-utils.h>
 
 #include "gedit-file-browser-store.h"
@@ -197,14 +196,13 @@ static void model_check_dummy                               (GeditFileBrowserSto
 static void next_files_async 				    (GFileEnumerator        *enumerator,
 							     AsyncNode              *async);
 
-GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE (GeditFileBrowserStore, gedit_file_browser_store,
-			G_TYPE_OBJECT,
-			GEDIT_PLUGIN_IMPLEMENT_INTERFACE (gedit_file_browser_store_tree_model,
-							  GTK_TYPE_TREE_MODEL,
-							  gedit_file_browser_store_iface_init)
-			GEDIT_PLUGIN_IMPLEMENT_INTERFACE (gedit_file_browser_store_drag_source,
-							  GTK_TYPE_TREE_DRAG_SOURCE,
-							  gedit_file_browser_store_drag_source_init))
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditFileBrowserStore, gedit_file_browser_store,
+				G_TYPE_OBJECT,
+				0,
+				G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL,
+						       gedit_file_browser_store_iface_init)
+				G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_DRAG_SOURCE,
+						       gedit_file_browser_store_drag_source_init))
 
 /* Properties */
 enum {
@@ -427,6 +425,11 @@ gedit_file_browser_store_class_init (GeditFileBrowserStoreClass *klass)
 				  sizeof (GeditFileBrowserStorePrivate));
 }
 
+static void
+gedit_file_browser_store_class_finalize (GeditFileBrowserStoreClass *klass)
+{
+}
+
 static void
 gedit_file_browser_store_iface_init (GtkTreeModelIface *iface)
 {
@@ -3777,4 +3780,10 @@ gedit_file_browser_store_new_directory (GeditFileBrowserStore *model,
 	return result;
 }
 
+void
+_gedit_file_browser_store_register_type (GTypeModule *type_module)
+{
+	gedit_file_browser_store_register_type (type_module);
+}
+
 /* ex:ts=8:noet: */
