@@ -42,7 +42,7 @@ class PythonConsole(Gtk.ScrolledWindow):
     DEFAULT_FONT = "Monospace 10"
 
     CONSOLE_KEY_BASE = 'org.gnome.gedit.plugins.pythonconsole'
-    SETTINGS_INTERFACE_DIR = "org.gnome.Desktop.Interface"
+    SETTINGS_INTERFACE_DIR = "org.gnome.desktop.interface"
     SETTINGS_PROFILE_DIR = "org.gnome.GnomeTerminal.profiles.Default"
 
     CONSOLE_KEY_COMMAND_COLOR = 'command-color'
